import sys
import socket
import string
from ricebox import special
import datetime

def connect():

    HOST="irc.freenode.net"
    PORT=6667
    NICK="specialbot"
    IDENT="special"
    REALNAME="Specialbot"
    readbuffer=""

    s=socket.socket( )
    s.connect((HOST, PORT))
    s.send("NICK %s\r\n" % NICK)
    s.send("USER %s %s bla :%s\r\n" % (IDENT, HOST, REALNAME))
    s.send("JOIN #rubber\r\n")
            
    commands = {"!special":special.getSpecial, "!tomorrow":special.getSpecialTomorrow, "!named":special.getSpecialByName, "!quit":lambda: sys.exit(0)}
    
    last = 0
    counter = 0
    
    while True:
        counter += 1
        readbuffer=readbuffer+s.recv(1024)
        temp=string.split(readbuffer, "\n")
        #print temp
        readbuffer=temp.pop( )
        dotm = datetime.datetime.now().day
        
        if counter > 13 and dotm != last and datetime.datetime.now().hour >= 11:
            if "weet" in special.getSpecial() or "urry" in special.getSpecial():
                s.send("PRIVMSG #rubber :Excuse me gents, the special today is %s.\n" % (special.getSpecial()))
            last = dotm
        
        
        for line in temp:
            line=string.rstrip(line)
            line=string.split(line)

            if(line[0]=="PING"):
                s.send("PONG %s\r\n" % line[1])

            if(line[1]=="INVITE"):
                s.send("JOIN #rubber\r\n")

            for command, result in commands.items():
                if(line[1]=="PRIVMSG" and line[2]=="#rubber" and command in " ".join(line)):
                    if command == '!named':
                        search_text = list(line[line.index(':!named')+1:])
                        s.send("PRIVMSG #rubber :%s\r\n" % result(search_text))
                    else:
                        s.send("PRIVMSG #rubber :%s\r\n" % result())
            


#!/usr/local/bin/python
"""
	Ricebox daily special getter :)
	by Alan & Matt
"""


import httplib
import sgmllib
import time
from datetime import datetime,timedelta
import sys

class RbParser(sgmllib.SGMLParser):
	div_results = []
	in_day=False
	day_text=[]
	
	def start_div(self, attrs):
		for attr in attrs:
			if attr[0].lower()=='class' and attr[1].lower().find('normal')!=-1:
				self.in_day=True
				self.day_text=[]
		
	def end_div(self):
		if self.in_day:
			self.in_day=False
			if self.day_text:
				self.div_results.append(self.day_text)
	
	def handle_data(self,text):
		if self.in_day:
			filtered_text = text
			for bad_char in [' ','\n','\r']:
				filtered_text = filtered_text.replace(bad_char,'')
			if filtered_text:
				self.day_text.append(text)

			
def parse_url(URL):
	result = {}
	URL = URL.replace("http://","")
	host = URL[:URL.index("/")]
	path = URL[URL.index("/"):]
	filename = URL.split("/")[len(URL.split("/"))-1]
	result = {'host':host,'path':path,'filename':filename}
	return result
	

def get_url(URL):
	URL = parse_url(URL)
	conn = httplib.HTTPConnection(URL['host'])
	conn.putrequest("GET",URL['path'])
	conn.endheaders()
	result = conn.getresponse()
	body = result.read()
	conn.close()
	return body


def getParsedBody():
    body = get_url("http://freespace.virgin.net/kuanwai.law/page3.html")
    #Got response
    p = RbParser()
    p.feed(body)
    return p



def getNiceName(in_div):
	result = ""
	for idx in range(1,len(in_div)):
		next_word = str(in_div[idx]).strip()
		
		#Can't be arsed fixing my parser
		if next_word.lower() == 'fried' and idx==len(in_div)-1:
			next_word = 'Fried Rice'
		result = result + next_word
		if result[len(result)-1] not in ['-']:
			result = result + " "
	return result[:len(result)-1]

def getSpecialByName(search_text=None):
    p = getParsedBody()
    search_text = [a.lower() for a in search_text]
    
    for common_word in ['and','or']:
    	if common_word.lower() in search_text:
    		search_text.remove(common_word)
    
    best_match = -1
    best_match_div = []
    day_of_month = datetime.now().day
    for div in p.div_results:
    	div_text = ' '.join(div)
    	match = 0
    	for word in search_text:
    		if word.lower() in div_text.lower():
    			match = match + 1
       			if match > best_match and str(div[0]).isdigit() and int(div[0]) >= int(day_of_month): 
       				best_match = match
         			best_match_div = div
    if best_match_div:
    	today_weekday = datetime.now().weekday()
    	special_day = int(best_match_div[0])
    	offset = special_day - day_of_month
    	if offset <= 7:
    		days = ['Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday']
    	 	return "%s on %s" % (getNiceName(best_match_div),days[(today_weekday+offset)%7])
    	else:
    		special_date = datetime(datetime.now().year,datetime.now().month,special_day)
    		return getNiceName(best_match_div) + " on %s/%s" % (special_date.day,special_date.month)
    	

def getSpecialByDate(date=None):
    p = getParsedBody()
    if not date:
    	day_of_month = datetime.now().day
    else:
    	day_of_month = date.day
    
    found_special = False
    for div in p.div_results:
      if str(div[0]) == str(day_of_month):
      	return getNiceName(div)
    	found_special=True

    if not found_special:
      return None

def getSpecialTomorrow():
	return getSpecialByDate(date=datetime.now() + timedelta(days=1))

def getSpecial(date=None):
	return getSpecialByDate(date=datetime.now())

def get(args=None):
    argv = sys.argv
    if '-t' in argv:
    	special = getSpecialTomorrow()
    	if special:
    		print "The special tomorrow is: %s" % (special)
    	else:
    		print "There is no special tomorrow"
        return True
    
    if '-n' in argv:
     	search_text = list(argv[argv.index('-n')+1:])
     	print getSpecialByName(search_text)
     	return True

    special = getSpecial()
    if special:
    	print "Today's special is: %s" % (special)
    	return True

if __name__ == "__main__":
	get()


from setuptools import setup, find_packages
import sys, os

version = '0.1.3'

setup(name='ricebox',
      version=version,
      description="Grabs the daily special from the rice box in bristol.",
      long_description="""\
Scrapes the Rice Box's website and returns the current daily special.""",
      classifiers=["Environment :: Console",
                   "Intended Audience :: Other Audience",
                   "Natural Language :: English",
                   "Topic :: Other/Nonlisted Topic"], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='rice box chinese',
      author='Alan Hoey',
      author_email='alan.hoey@teamrubber.com',
      url='http://freespace.virgin.net/kuanwai.law/page3.html',
      license='GPL',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
	      'setuptools',
          # -*- Extra requirements: -*-      
      ],
      entry_points={
      'console_scripts': [
                  'special = ricebox.special:get',
                  'specialbot = ricebox.bot:connect',
              ],
      },
      )
